<?php
/**
 * the-consult functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package the-consult
 */

if ( ! function_exists( 'the_consult_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function the_consult_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on the-consult, use a find and replace
		 * to change 'the-consult' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'the-consult', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('the-consult-slider-image', 1920, 900, true);
		add_image_size('the-consult-feature-thumb', 128, 128, true);
		add_image_size('the-consult-latest-news-thumb', 500, 400, true);
		add_image_size('the-consult-testimonial-thumb', 400, 400, true);
		add_image_size('the-consult-archive-image', 1170, 700, true);
        add_image_size('the-consult-portfolio', 330, 340, true);
        add_image_size('the-consult-recent-post-thumb', 150, 150, true);
        
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'the-consult-menu-1' => esc_html__( 'Primary', 'the-consult' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'the_consult_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 70,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'the_consult_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function the_consult_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'the_consult_content_width', 640 );
}
add_action( 'after_setup_theme', 'the_consult_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function the_consult_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'the-consult' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'the-consult' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

    register_sidebar( array(
		'name'          => esc_html__( 'Left Sidebar', 'the-consult' ),
		'id'            => 'the-consult-sidebar-left',
		'description'   => esc_html__( 'Add widgets here.', 'the-consult' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
        'name' => esc_html__('Footer One','the-consult'),
        'id' => 'the-consult-footer-one',
        'description' => esc_html__('Appears in the buttom of footer area','the-consult'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ) );

    register_sidebar( array(
        'name' => esc_html__('Footer Two','the-consult'),
        'id' => 'the-consult-footer-two',
        'description' => esc_html__('Appears in the buttom of footer area','the-consult'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ) );

    register_sidebar( array(
        'name' => esc_html__('Footer Three','the-consult'),
        'id' => 'the-consult-footer-three',
        'description' => esc_html__('Appears in the buttom of footer area','the-consult'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ) );

    register_sidebar( array(
        'name' => esc_html__('Footer Four','the-consult'),
        'id' => 'the-consult-footer-four',
        'description' => esc_html__('Appears in the buttom of footer area','the-consult'),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ) );

}
add_action( 'widgets_init', 'the_consult_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function the_consult_scripts() {
	$the_consult_font_query_args = array('family' => 'Lato:100,100i,300,300i,400,400i,700,700i,900,900i');
    wp_enqueue_style('the-consult-google-fonts', add_query_arg($the_consult_font_query_args, "//fonts.googleapis.com/css"));
	wp_enqueue_style('owl-carousel',get_template_directory_uri().'/js/owl-carousel/owl.carousel.css');
	wp_enqueue_style('font-awesome-min', get_template_directory_uri() . '/library/font-awesome/css/font-awesome.min.css', array(), '4.6.3' );
    wp_enqueue_style('the-consult-style', get_stylesheet_uri() );
	wp_enqueue_style('the-consult-responsive',get_template_directory_uri().'/responsive.css');
    
	wp_enqueue_script( 'jquery-sticky', get_template_directory_uri() . '/library/jquery-sticky/js/jquery.sticky.js', array( 'jquery' ));
	wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . '/js/waypoints/jquery.waypoints.min.js', array( 'jquery' ));
	wp_enqueue_script('jquery-counterup-min', get_template_directory_uri() . '/js/counterup/js/jquery.counterup.min.js', array( 'jquery' ));
	wp_enqueue_script('owl-carousel',get_template_directory_uri().'/js/owl-carousel/owl.carousel.js',array('jquery'));
    wp_enqueue_script('the-consult-navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'));
    wp_enqueue_script('the-consult-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'));
    wp_enqueue_script('the-consult-custom',get_template_directory_uri().'/js/custom.js', array('jquery'));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'the_consult_scripts' );

/** Implement the Custom Header feature. **/
require get_template_directory() . '/inc/custom-header.php';

/** Custom template tags for this theme. **/
require get_template_directory() . '/inc/template-tags.php';

/** Recent Post Widget **/
require get_template_directory() . '/inc/widgets/widgets-recent-post.php';

/** Widget Fields **/
require get_template_directory() . '/inc/widgets/widgets-field.php';

/** Functions which enhance the theme by hooking into WordPress. **/
require get_template_directory() . '/inc/template-functions.php';

/** Customizer additions. **/
require get_template_directory() . '/inc/customizer.php';

/** Load Custom functions file. **/
require get_template_directory() . '/inc/the-consult-functions.php';

/** Load Custom Customizer file. **/
require get_template_directory() . '/inc/the-consult-customizer.php';

/** Metaboxe **/
require get_template_directory() . '/inc/the-consult-metabox.php';
